@@ -31,7 +31,12 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
                 "Validate Azure Pipelines config against the schema provided "
                 "by Microsoft"
             ),
-            "add_args": ["--data-transform", "azure-pipelines"],
+            "add_args": [
+                "--data-transform",
+                "azure-pipelines",
+                "--regex-variant",
+                "nonunicode",
+            ],
             "files": r"^(\.)?azure-pipelines\.(yml|yaml)$",
             "types": "yaml",
         },
@@ -140,6 +145,18 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "types": "yaml",
         },
     },
+    "mergify": {
+        "url": "https://docs.mergify.com/mergify-configuration-schema.json",
+        "hook_config": {
+            "name": "Validate Mergify config",
+            "files": [
+                r"\.mergify\.yml",
+                r"\.mergify/config\.yml",
+                r"\.github/mergify\.yml",
+            ],
+            "types": "yaml",
+        },
+    },
     "readthedocs": {
         "url": _githubusercontent_url(
             "readthedocs",
@@ -168,7 +185,8 @@ SCHEMA_CATALOG: dict[str, dict[str, t.Any]] = {
             "files": [
                 r"renovate\.(json|json5)",
                 r"\.(github|gitlab)/renovate\.(json|json5)",
-                r"\.renovaterc(\.json)?",
+                r"\.renovaterc",
+                r"\.renovaterc\.(json|json5)",
             ],
         },
     },
